#  Useful information about BK1086 and BK1088E devices


* The BK1086 only provides support for FM and AM, whereas the BK1088 adds support for SW and LW in addition to FM and AM.
* The input DC operating point of the front-end low-noise amplifier in the BK1086/88 chip has been internally set to 0V. Therefore, when using the ground wire as the antenna input, there is no need for a DC blocking capacitor. However, if a DC blocking capacitor (100pF for FM mode, 270nF for MW mode) is present in the external circuit design, it will not impact the receiving performance.
* Including an LC resonant circuit can significantly enhance the FM receiving sensitivity. If there is a high demand for improved performance in this aspect, it is necessary to incorporate it into the circuit design.
* The BK1086/88 chip requires an input clock accuracy of less than 200ppm. When using an external input clock frequency of 32.768KHz, the required peak-to-peak value of the clock signal should exceed 750mV. For an external input clock frequency of 24MHz, the required peak-to-peak value of the clock signal for BK1086/88 is greater than 1.35V. The waveform of the clock signal is not restricted.
* Question: After completing the initialization process without any issues, I am unable to find the corresponding station after setting the frequency. Alternatively, there is a significant deviation between the frequency displayed in the channel list and the actual station frequency after an automatic search. How can I resolve this problem? Answer: The mentioned situation suggests that the reference clock might not be functioning properly. To address this, please follow the steps below: 1) Verify that the clock input mode selection in the initialization settings is correctly configured. 2) If an external clock input is utilized, use an oscilloscope to directly examine the RCLK signal to determine if the input clock meets the specified requirements. 3) In the case of an internal crystal oscillator circuit, employ an oscilloscope to directly check the RCLK signal and confirm if it initiates oscillation. 4) Ensure that the provided initialization file by Beken corresponds to the reference clock of 32.768kHz.
* Question: How should the internal registers be configured when using reference clocks with different frequencies? Answer: To adapt to the specific clock signal used, the internal registers should be set as follows: 1) Calculate the value using the formula (Freq/512)+0.5, resulting in an 18-bit hexadecimal number. 2) Set Bit[17:16] of REG28 to the corresponding values and set Bit[15:0] of REG29 to the reverse order of the lower 16 bits of the calculated binary number. 3) Note that the bit order of REG29 is opposite to the calculation result. Bit[15] corresponds to REG29[0], and Bit[0] corresponds to REG29[15]. For example, if the frequency is 12MHz: Calculate (12000000/512) + 0.5 = 23438. Convert it to hexadecimal: 0x5B8E. Convert the lower 16 bits to binary and reverse the order: 0111 0001 1101 1010. Convert it back to hexadecimal: 0x71DA. Therefore, the configuration for the 12MHz clock would be: REG28 remains unchanged at 0x0000, and REG29 changes from 0x0200 to 0x71DA.
* Question: After listening to the radio station normally, when I exit the FM function and then enter it again, I only hear background noise instead of the desired radio state that was present when I last exited. Why does this happen? Answer: This phenomenon can be attributed to the system not reaching a stable state after being powered down and turned on again, particularly during the initialization process. To resolve this issue, it is recommended to increase the delay between the initialization and frequency setting stages appropriately. By allowing sufficient time for the system to stabilize, you can ensure that the desired radio state is restored upon re-entering the FM function.
* Why are read and write operations to registers very unstable, sometimes successful and sometimes failing? The mentioned situation is typically caused by factors such as long I2C control lines or slight interference. To address this issue, one possible solution is to reduce the value of the pull-up resistors. By doing so, the pull-up capability can be enhanced, resulting in improved stability during read and write operations to the registers.
* In many systems, 12MHz or 24MHz is often used as the system clock, so that their harmonics 96M Just falls within the FM band. To minimize the effect of this harmonic, optimize as follows: 1) Optimize the PCB layout design. 2) If you use the headphone cable as an FM antenna, please add isolation beads; 3) In the system application, when using the FM function, minimize the work of other modules; 4) Minimize the drive capability of the crystal oscillator circuit; 5) When possible, reduce the main frequency of the system clock, so that the harmonic interference is greatly reduced.
* Reg8 (bit7~15) is an important parameter for judging frequency offset. In BK1080, this parameter is called Freqd. The AFC of BK1088 has an enable bit AFCEN which is Reg8 (bit15). Set to 1 to enable.
Defaults to 1 at initialization and is enabled. If the program is running, turn off this bit. The AFC reading will always be 0, resulting in frequent frequency deviations.
* Reg2 (bit6) of BK1088 is the chip power down enable bit, if this bit is accidentally set to 1, it will make the chip
Go to sleep, check the state of this bit. Also check if the chip mute bit is set.
* How should I choose the ferrite antenna for the BK1086/88? What are the specifications for the BK1086/88 antenna? A: The selection of a magnetic rod antenna for the BK1086/88 follows the following principles: 1) Generally, a longer and thicker magnetic rod tends to provide better performance. However, factors like cost and product shape should also be considered. 2) High Q cores are preferable over normal cores for improved performance. 3) In principle, a magnetic rod with more coil cores is better. For instance, a magnetic rod with seven cores would perform better than one with five cores. 4) The number of turns in the coil should not be maximized. Initially, you can wind a certain number of turns (e.g., 150 turns) and adjust the number of coils based on the observed effect to achieve optimal results. In summary, fine-tuning the magnetic rod antenna requires specialized equipment and experienced technicians. If your company lacks the necessary resources, it is advisable to engage a professional antenna manufacturer with relevant expertise and equipment to customize the boards and casings for you.





